<?php

namespace Groot\Covid19\Repository;

use Groot\Covid19\Covid19 as Covid19Client;
use XF\Db\DuplicateKeyException;
use XF\Mvc\Entity\Repository;

class Covid19Countries extends Repository{

    public function getCountries($order = 'id', $desc = 'DESC')
    {
        return
            $this->finder('Groot\Covid19:Covid19Countries')
                ->order($order, $desc)
                ->fetch();
    }

    public function getCountry($country, $createIfNotExist = false)
    {
        $market = $this->em->findOne('Groot\Covid19:Covid19Countries', ['country' => $country]);

        if(!$market && $createIfNotExist)
            $market = $this->em->create('Groot\Covid19:Covid19Countries');

        return $market;
    }

    public function fetchCountriesData()
    {
        $data = [];

        $client = new Covid19Client();

        $data = $client->request('countries');

        foreach ($data as $id => $country) {

            $existingData = $this->getCountry($country['country'], true);

            $existingData->bulkSet([
                'country' => $country['country'],
                'iso2' => is_null($country['countryInfo']['iso2']) ? 'undefined' : $country['countryInfo']['iso2'],
                'iso3' => is_null($country['countryInfo']['iso3']) ? 'undefined' : $country['countryInfo']['iso3'],
                'flag' => $country['countryInfo']['flag'],
                'cases' => $country['cases'],
                'todayCases' => $country['todayCases'],
                'deaths' => $country['deaths'],
                'todayDeaths' => $country['todayDeaths'],
                'recovered' => $country['recovered'],
                'active' => $country['active'],
                'critical' => $country['critical'],
                'casesPerOneMillion' => $country['casesPerOneMillion'],
                'deathsPerOneMillion' => $country['deathsPerOneMillion'],
                'tests' => $country['tests'],
                'testsPerOneMillion' => $country['testsPerOneMillion'],
                'continent' => $country['continent'],
                'updated' => \XF::$time
            ]);

            try {
                $existingData->save(false);
            }
                /** @noinspection PhpRedundantCatchClauseInspection */
            catch (DuplicateKeyException $e) {

            }

        }

    }

}