<?php

namespace Groot\Covid19\Widget;

use Groot\Covid19\Repository\Covid19Countries;
use XF\Widget\AbstractWidget;

class Covid19 extends AbstractWidget
{
    protected $defaultOptions = [
        'country' => 'all',
        'style' => 1,
        'darkStyle' => 0,
    ];

    protected function getDefaultTemplateParams($context)
    {
        $params = parent::getDefaultTemplateParams($context);
        if ($context == 'options')
        {
            /** @var Covid19Countries $covid19CountriesRepo */
            $covid19CountriesRepo = $this->repository('Groot\Covid19:Covid19Countries');
            $params['countries']  = $covid19CountriesRepo->getCountries();
        }
        return $params;
    }

    public function render()
    {
        $title = $this->getTitle();

        if($this->options['country'] != 'all')
        {
            /** @var Covid19Countries $covid19CountriesRepo */
            $covid19CountriesRepo = $this->repository('Groot\Covid19:Covid19Countries');
            $data = $covid19CountriesRepo->getCountry($this->options['country']);
            $title = $data->country;
        }
        else
        {
            /** @var \Groot\Covid19\Repository\Covid19 $covid19GlobalRepo */
            $covid19GlobalRepo = $this->repository('Groot\Covid19:Covid19');
            $data = $covid19GlobalRepo->getGlobalData();
        }

        if(!$title)
            $title = \XF::phrase('groot_covid19_label_global');


        $viewParams = [
            'title' => $title,
            'data' => $data,
            'style' => $this->options['style'],
            'darkStyle' => $this->options['darkStyle'],
        ];

        return $this->renderer('groot_covid19_simple', $viewParams);
    }

    public function verifyOptions(\XF\Http\Request $request, array &$options, &$error = null)
    {
        $options = $request->filter([
            'country' => 'str',
            'style' => 'int',
            'darkStyle' => 'int',
        ]);
        return true;
    }
}