<?php

namespace Groot\Covid19\Widget;

use Groot\Covid19\Covid19 as Covid19Client;
use Groot\Covid19\Repository\Covid19Countries;
use Groot\Covid19\Repository\Covid19History;
use XF\Widget\AbstractWidget;

class Covid19Chart extends AbstractWidget
{
    protected $defaultOptions = [
        'country' => 'all',
        'start' => null,
        'end' => null,
        'grouping' => 'daily',
        'incraw' => true,
    ];

    protected function getDefaultTemplateParams($context)
    {
        $params = parent::getDefaultTemplateParams($context);
        if ($context == 'options')
        {
            /** @var Covid19Countries $covid19CountriesRepo */
            $covid19CountriesRepo = $this->repository('Groot\Covid19:Covid19Countries');
            $params['countries']  = $covid19CountriesRepo->getCountries();

            $params['datePresets'] = \XF::language()->getDatePresets(strtotime('2019-01-01'));
        }

        return $params;
    }

    public function render()
    {
        $title = $this->getTitle();
        $historyRepo = $this->getCovid19HistoryRepo();

        $grouping = $this->options['grouping'];

        if (!$grouping || !isset($this->app['stats.groupings'][$grouping]))
        {
            $grouping = 'daily';
        }

        /** @var \XF\Stats\Grouper\AbstractGrouper $grouper */
        $grouper = $this->app->create('stats.grouper', $grouping);

        $displayTypes = ['confirmed', 'deaths', 'recovered'];
        $displayTypes = array_slice($displayTypes, 0, 15);


        $start = ($this->options['start'] == 0) ? strtotime('-1 month') : $this->options['start'];
        $end = ($this->options['end'] == 0) ? strtotime('-1 day') : $this->options['end'];

        $grapher = $this->service('XF:Stats\Grapher', $start, $end, $displayTypes);
        $data = $grapher->getGroupedData($grouper);

        if(!$title)
            $title = \XF::phrase('groot_covid19_label_global');


        $viewParams = [
            'title' => $title,
            'grouping' => $grouping,
            'displayTypes' => $displayTypes,
            'displayTypesPhrased' => $historyRepo->getStatsTypePhrases($displayTypes),
            'data' => $data,

            'start' => $start,
            'end' => $end,
            'endDisplay' => ($end >= \XF::$time ? 0 : $end),

            'includeRaw' => $this->options['incraw'],
        ];

        return $this->renderer('groot_covid19_chart', $viewParams);
    }

    public function verifyOptions(\XF\Http\Request $request, array &$options, &$error = null)
    {
        $options = $request->filter([
            'country' => 'str',
            'start' => 'datetime',
            'end' => 'datetime',
            'grouping' => 'str',
            'incraw' => 'bool',
        ]);
        return true;
    }

    /**
     * @return \XF\Mvc\Entity\Repository|Covid19History
     */
    protected function getCovid19HistoryRepo()
    {
        return $this->repository('Groot\Covid19:Covid19History');
    }
}